==> php-residence_0.2.4.tar.gz: php-residence/crearegole.php <==
<html>
<header>
<title> Crearegole php-residence </title>
</header>
<body bgcolor=#ffffff>

<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "crearegole.php";

include ("dati/connessione_db.php");
include ("includes/funzioni.php");
$tableregole = regole . $anno;
$tableperiodi = periodi . $anno;
$tablenometariffe = ntariffe . $anno;


if ($inserisci) {
pg_exec("begin");
pg_exec("lock table $tableregole");

if ($regola_1) {
if (!$inizioperiodo or !$fineperiodo or !$appartamento) {
echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
} # fine if (!$inizioperiodo or !$fineperiodo or !$appartamento)
else {
$idinizioperiodo = pg_exec("select idperiodi from $tableperiodi where datainizio = '$inizioperiodo' ");
if (pg_numrows($idinizioperiodo) == 0) $idinizioperiodo = 9999999;
else $idinizioperiodo = pg_result($idinizioperiodo,0,idperiodi);
$idfineperiodo = pg_exec("select idperiodi from $tableperiodi where datafine = '$fineperiodo' ");
if (pg_numrows($idfineperiodo) == 0) $idfineperiodo = 0;
else $idfineperiodo = pg_result($idfineperiodo,0,idperiodi);
if ($idfineperiodo < $idinizioperiodo) {
echo mex("Le date sono sbagliate",$pag).".<br>";
} # fine if ($idfineperiodo < $idinizioperiodo)
else {
$vecchia_regola = pg_exec("select * from $tableregole where app_agenzia = '$appartamento' and iddatainizio <= $idfineperiodo and iddatafine >= $idinizioperiodo");
$num_vecchia_regola = pg_numrows($vecchia_regola);
if ($num_vecchia_regola != 0) {
echo mex("Esiste gi una regola di questo tipo nell'appartamento e nel periodo selezionato",$pag).".<br>";
} # fine if ($num_vecchia_regola != 0)
else {
$idregole = pg_exec("select max(idregole) from $tableregole");
$idregole = pg_result($idregole,0,max);
$idregole = $idregole + 1;
pg_exec("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ($idregole,'$appartamento', $idinizioperiodo, $idfineperiodo)");
if ($motivazione) pg_exec("update $tableregole set motivazione = '$motivazione' where idregole = $idregole");
echo mex("La regola  stata inserita",$pag).".";
} # fine else if ($num_vecchia_regola != 0)
} # fine else if ($idfineperiodo < $idinizioperiodo)
} # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
} # fine if ($regola_1)

if ($canc_regola_1) {
if ($gia_stato) {
pg_exec("delete from $tableregole where app_agenzia != ''");
echo mex("Le regole sono state cancellate",$pag);
} # fine if ($gia_stato)
else {
echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
<input type=\"hidden\" name=\"canc_regola_1\" value=\"$canc_regola_1\">
<input type=\"submit\" name=\"gia_stato\" value=\"  ".mex("SI",$pag)."  \"></form>";
} # fine else if ($gia_stato)
} # fine if ($canc_regola_1)

if ($regola_2) {
if (!$tipotariffa) {
$inserire = "NO";
echo mex("Si deve scegliere la tariffa",$pag).".<br>";
} # fine if (!$tipotariffa)
else {
$regola_esistente = pg_exec("select * from $tableregole where tariffa_per_app = '$tipotariffa'");
$num_regole_esistente = pg_numrows($regola_esistente);
if ($num_regole_esistente != 0) {
$inserire = "NO";
echo mex("La tariffa scelta ha gi degli appartamenti associati, cancella la regola prima di inserirne una nuova",$pag).".<br>";
} # fine if ($num_regole_esistente != 0)
} # fine else if (!$tipotariffa)
if (!$lista_app) {
$inserire = "NO";
echo mex("Si deve inserire almeno un appartamento da associare",$pag).".<br>";
} # fine if (!$lista_app)
else {
$appartamenti = pg_exec ("select idappartamenti from appartamenti");
$num_appartamenti = pg_numrows ($appartamenti);
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$appartamento = pg_result($appartamenti,$num1,idappartamenti);
$app_esistente[$appartamento] = "SI";
} # fine for $num1
$vett_app = explode(",",$lista_app);
$num_app = count($vett_app);
for ($num1 = 0 ; $num1 < $num_app ; $num1 = $num1 + 1) {
if ($app_esistente[$vett_app[$num1]] != "SI") {
$inserire = "NO";
echo mex("L'appartamento ",$pag).$vett_app[$num1].mex(" non esiste",$pag).".<br>";
} # fine if ($app_esistente[$appartamento] != "SI")
} # fine for $num1
} # fine else if (!$lista_app)
if ($inserire != "NO") {
$idregole = pg_exec("select max(idregole) from $tableregole");
$idregole = pg_result($idregole,0,max);
$idregole = $idregole + 1;
pg_exec("insert into $tableregole (idregole,tariffa_per_app,motivazione) values ($idregole,'$tipotariffa', '$lista_app')");
echo mex("La regola di assegnazione 2  stata inserita",$pag).".<br>";
} # fine if ($inserire != "NO")
} # fine if ($regola_2)

pg_exec("commit");

echo "
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\">";
} # fine if ($inserisci)

else {


# Form iniziale di inserimento
echo "<br><center><font size=+2>".mex("Inserisci le regole di assegnazione per le prenotazioni dell'anno",$pag)." $anno
</font></center><br><hr width=\"95%\">
<center>".mex("Regola di assegnazione",$pag)." <b>1</b>.</center><br>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
".mex("Chiedi prima di assegnare l'appartamento",$pag)." <select name=\"appartamento\">
<option value=\"\" selected>--</option>";
include("dati/selectappartamenti.php");
echo "</select> ".mex("nel periodo dal",$pag)." 
<select name=\"inizioperiodo\">";
include("dati/selectperiodi$anno.php");
echo "
</select>
".mex("al",$pag)." <select name=\"fineperiodo\">";
include("dati/selectperiodi$anno.php");
echo "</select><br>".mex("motivazione",$pag).":
 <input type=\"text\" name=\"motivazione\" size=\"30\" maxlength=\"30\">
 (".mex("opzionale",$pag).")<br><center>
<input type=\"submit\" name=\"regola_1\" value=\"".mex("Inserisci la regola",$pag)." 1\">
</form></center>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
<input type=\"submit\" name=\"canc_regola_1\" value=\"".mex("Cancella tutte le regole di questo tipo",$pag)."\">
</form><hr width=\"95%\">

<center>".mex("Regola di assegnazione",$pag)." <b>2</b>.</center><br>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
".mex("Quando si sceglie la tariffa",$pag)."
<select name=\"tipotariffa\">
<option value=\"\" selected>----</option>";
$rigatariffe = pg_exec("select * from $tablenometariffe where idntariffe = 1 ");
for ($numtariffa = 1 ; $numtariffa < 11 ; $numtariffa = $numtariffa + 1) {
$tariffa = "tariffa".$numtariffa;
$tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
$nometariffa = pg_result($rigatariffe,0,$tariffa);
if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
else $nometariffa_vedi = "";
echo "
<option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
} # fine for $numtariffa
echo "</select>
 ".mex("assegna automaticamente gli appartamenti",$pag)."
 <input type=\"text\" name=\"lista_app\" size=\"15\"> (".mex("lista di appartamenti separati da virgole",$pag).")
 ".mex("se non si inserisce nessun altro metodo di assegnazione",$pag).".<br>";
echo "<center>
<input type=\"submit\" name=\"regola_2\" value=\"".mex("Inserisci la regola",$pag)." 2\">
</center></form>";
echo "<hr width=\"95%\"><center><br>
<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"regole\">
<input type=\"submit\" name=\"visualizza\" value=\"".mex("Vedi le regole gi inserite",$pag)."\">
</form>
<form method=\"post\" action=\"inizio.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">
<br></center></form>";


} # fine else if ($inserisci)


?>

</body>
</html>

==> php-residence_0.3.tar.gz: php-residence/crearegole.php <==
<html>
<header>
<title> Crearegole php-residence </title>
</header>
<body bgcolor=#ffffff>

<?php

##################################################################################
#    PHP-RESIDENCE
#    Copyright (C) 2001-2002 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##################################################################################

$pag = "crearegole.php";

include("./dati/dati_connessione.php");
include("./includes/funzioni_$PHPR_DB_TYPE.php");
connetti_db($PHPR_DB_NAME,$PHPR_DB_HOST,$PHPR_DB_PORT,$PHPR_DB_USER,$PHPR_DB_PASS,$PHPR_LOAD_EXT);
include ("./includes/funzioni.php");
$tableregole = regole . $anno;
$tableperiodi = periodi . $anno;
$tablenometariffe = ntariffe . $anno;


if ($inserisci) {
$tabelle_lock = array("$tableregole");
$altre_tab_lock = array("$tableperiodi","appartamenti");
$tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);

if ($regola_1) {
if (!$inizioperiodo or !$fineperiodo or !$appartamento) {
echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
} # fine if (!$inizioperiodo or !$fineperiodo or !$appartamento)
else {
$idinizioperiodo = esegui_query("select idperiodi from $tableperiodi where datainizio = '$inizioperiodo' ");
if (numlin_query($idinizioperiodo) == 0) $idinizioperiodo = 9999999;
else $idinizioperiodo = risul_query($idinizioperiodo,0,idperiodi);
$idfineperiodo = esegui_query("select idperiodi from $tableperiodi where datafine = '$fineperiodo' ");
if (numlin_query($idfineperiodo) == 0) $idfineperiodo = 0;
else $idfineperiodo = risul_query($idfineperiodo,0,idperiodi);
if ($idfineperiodo < $idinizioperiodo) {
echo mex("Le date sono sbagliate",$pag).".<br>";
} # fine if ($idfineperiodo < $idinizioperiodo)
else {
$vecchia_regola = esegui_query("select * from $tableregole where app_agenzia = '$appartamento' and iddatainizio <= $idfineperiodo and iddatafine >= $idinizioperiodo");
$num_vecchia_regola = numlin_query($vecchia_regola);
if ($num_vecchia_regola != 0) {
echo mex("Esiste gi una regola di questo tipo nell'appartamento e nel periodo selezionato",$pag).".<br>";
} # fine if ($num_vecchia_regola != 0)
else {
$idregole = esegui_query("select max(idregole) from $tableregole");
$idregole = risul_query($idregole,0,0);
$idregole = $idregole + 1;
esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,iddatafine) values ($idregole,'$appartamento', $idinizioperiodo, $idfineperiodo)");
if ($motivazione) esegui_query("update $tableregole set motivazione = '$motivazione' where idregole = $idregole");
echo mex("La regola  stata inserita",$pag).".";
} # fine else if ($num_vecchia_regola != 0)
} # fine else if ($idfineperiodo < $idinizioperiodo)
} # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
} # fine if ($regola_1)

if ($canc_regola_1) {
if ($gia_stato) {
esegui_query("delete from $tableregole where app_agenzia != ''");
echo mex("Le regole sono state cancellate",$pag);
} # fine if ($gia_stato)
else {
echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
<input type=\"hidden\" name=\"canc_regola_1\" value=\"$canc_regola_1\">
<input type=\"submit\" name=\"gia_stato\" value=\"  ".mex("SI",$pag)."  \"></form>";
} # fine else if ($gia_stato)
} # fine if ($canc_regola_1)

if ($regola_2) {
if (!$tipotariffa) {
$inserire = "NO";
echo mex("Si deve scegliere la tariffa",$pag).".<br>";
} # fine if (!$tipotariffa)
else {
$regola_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '$tipotariffa'");
$num_regole_esistente = numlin_query($regola_esistente);
if ($num_regole_esistente != 0) {
$inserire = "NO";
echo mex("La tariffa scelta ha gi degli appartamenti associati, cancella la regola prima di inserirne una nuova",$pag).".<br>";
} # fine if ($num_regole_esistente != 0)
} # fine else if (!$tipotariffa)
if (!$lista_app) {
$inserire = "NO";
echo mex("Si deve inserire almeno un appartamento da associare",$pag).".<br>";
} # fine if (!$lista_app)
else {
$appartamenti = esegui_query ("select idappartamenti from appartamenti");
$num_appartamenti = numlin_query ($appartamenti);
for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
$appartamento = risul_query($appartamenti,$num1,idappartamenti);
$app_esistente[$appartamento] = "SI";
} # fine for $num1
$vett_app = explode(",",$lista_app);
$num_app = count($vett_app);
for ($num1 = 0 ; $num1 < $num_app ; $num1 = $num1 + 1) {
if ($app_esistente[$vett_app[$num1]] != "SI") {
$inserire = "NO";
echo mex("L'appartamento ",$pag).$vett_app[$num1].mex(" non esiste",$pag).".<br>";
} # fine if ($app_esistente[$appartamento] != "SI")
} # fine for $num1
} # fine else if (!$lista_app)
if ($inserire != "NO") {
$idregole = esegui_query("select max(idregole) from $tableregole");
$idregole = risul_query($idregole,0,0);
$idregole = $idregole + 1;
esegui_query("insert into $tableregole (idregole,tariffa_per_app,motivazione) values ($idregole,'$tipotariffa', '$lista_app')");
echo mex("La regola di assegnazione 2  stata inserita",$pag).".<br>";
} # fine if ($inserire != "NO")
} # fine if ($regola_2)

unlock_tabelle($tabelle_lock);

echo "
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"ok\" value=\"".mex("Torna indietro",$pag)."\">";
} # fine if ($inserisci)

else {


# Form iniziale di inserimento
echo "<br><center><font size=+2>".mex("Inserisci le regole di assegnazione per le prenotazioni dell'anno",$pag)." $anno
</font></center><br><hr width=\"95%\">
<center>".mex("Regola di assegnazione",$pag)." <b>1</b>.</center><br>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
".mex("Chiedi prima di assegnare l'appartamento",$pag)." <select name=\"appartamento\">
<option value=\"\" selected>--</option>";
include("./dati/selectappartamenti.php");
echo "</select> ".mex("nel periodo dal",$pag)." 
<select name=\"inizioperiodo\">";
include("./dati/selectperiodi$anno.php");
echo "
</select>
".mex("al",$pag)." <select name=\"fineperiodo\">";
include("./dati/selectperiodi$anno.php");
echo "</select><br>".mex("motivazione",$pag).":
 <input type=\"text\" name=\"motivazione\" size=\"30\" maxlength=\"30\">
 (".mex("opzionale",$pag).")<br><center>
<input type=\"submit\" name=\"regola_1\" value=\"".mex("Inserisci la regola",$pag)." 1\">
</form></center>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
<input type=\"submit\" name=\"canc_regola_1\" value=\"".mex("Cancella tutte le regole di questo tipo",$pag)."\">
</form><hr width=\"95%\">

<center>".mex("Regola di assegnazione",$pag)." <b>2</b>.</center><br>
<form method=\"post\" action=\"crearegole.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"inserisci\" value=\"SI\">
".mex("Quando si sceglie la tariffa",$pag)."
<select name=\"tipotariffa\">
<option value=\"\" selected>----</option>";
$rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
$numero_tariffe = risul_query($rigatariffe,0,nomecostoagg);
for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
$tariffa = "tariffa".$numtariffa;
$tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
$nometariffa = risul_query($rigatariffe,0,$tariffa);
if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
else $nometariffa_vedi = "";
echo "
<option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
} # fine for $numtariffa
echo "</select>
 ".mex("assegna automaticamente gli appartamenti",$pag)."
 <input type=\"text\" name=\"lista_app\" size=\"15\"> (".mex("lista di appartamenti separati da virgole",$pag).")
 ".mex("se non si inserisce nessun altro metodo di assegnazione",$pag).".<br>";
echo "<center>
<input type=\"submit\" name=\"regola_2\" value=\"".mex("Inserisci la regola",$pag)." 2\">
</center></form>";
echo "<hr width=\"95%\"><center><br>
<form method=\"post\" action=\"visualizza_tabelle.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"hidden\" name=\"tipo_tabella\" value=\"regole\">
<input type=\"submit\" name=\"visualizza\" value=\"".mex("Vedi le regole gi inserite",$pag)."\">
</form>
<form method=\"post\" action=\"inizio.php\">
<input type=\"hidden\" name=\"anno\" value=\"$anno\">
<input type=\"submit\" name=\"torna\" value=\"".mex("Torna al men principale",$pag)."\">
<br></center></form>";


} # fine else if ($inserisci)


?>

</body>
</html>
